        function getT(rr,cc){
       if(rr==3 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==3 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>42</strong> miembros: 16 <br>2,7,8,9,10,14,16,20,21,28,32,39,40,41,42,49';}
       if(rr==3 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>6</strong> miembros: 13 <strong>control</strong><br>0,5,6,11,12,23,24,31,33,34,35,47,50';}
       if(rr==3 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>3,13,15,17,25,27,29,38,44,48';}
       if(rr==3 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>4</strong> miembros: 9 <br>1,4,18,19,30,37,43,45,46';}
       if(rr==3 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>36</strong> miembros: 3 <br>22,26,36';}
       if(rr==17 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==17 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>42</strong> miembros: 16 <br>2,7,8,9,10,14,16,20,21,28,32,39,40,41,42,49';}
       if(rr==17 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>6</strong> miembros: 13 <strong>control</strong><br>0,5,6,11,12,23,24,31,33,34,35,47,50';}
       if(rr==17 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>3,13,15,17,25,27,29,38,44,48';}
       if(rr==17 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>4</strong> miembros: 9 <br>1,4,18,19,30,37,43,45,46';}
       if(rr==17 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>36</strong> miembros: 3 <br>22,26,36';}
       if(rr==19 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==19 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>42</strong> miembros: 16 <br>2,7,8,9,10,14,16,20,21,28,32,39,40,41,42,49';}
       if(rr==19 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>6</strong> miembros: 13 <strong>control</strong><br>0,5,6,11,12,23,24,31,33,34,35,47,50';}
       if(rr==19 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>3,13,15,17,25,27,29,38,44,48';}
       if(rr==19 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>4</strong> miembros: 9 <br>1,4,18,19,30,37,43,45,46';}
       if(rr==19 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>36</strong> miembros: 3 <br>22,26,36';}
       if(rr==20 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==20 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>42</strong> miembros: 16 <br>2,7,8,9,10,14,16,20,21,28,32,39,40,41,42,49';}
       if(rr==20 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>6</strong> miembros: 13 <strong>control</strong><br>0,5,6,11,12,23,24,31,33,34,35,47,50';}
       if(rr==20 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>3,13,15,17,25,27,29,38,44,48';}
       if(rr==20 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>4</strong> miembros: 9 <br>1,4,18,19,30,37,43,45,46';}
       if(rr==20 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>36</strong> miembros: 3 <br>22,26,36';}
       if(rr==21 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==21 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>42</strong> miembros: 16 <br>2,7,8,9,10,14,16,20,21,28,32,39,40,41,42,49';}
       if(rr==21 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>6</strong> miembros: 13 <strong>control</strong><br>0,5,6,11,12,23,24,31,33,34,35,47,50';}
       if(rr==21 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>3,13,15,17,25,27,29,38,44,48';}
       if(rr==21 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>4</strong> miembros: 9 <br>1,4,18,19,30,37,43,45,46';}
       if(rr==21 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>36</strong> miembros: 3 <br>22,26,36';}
       if(rr==22 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==22 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>42</strong> miembros: 16 <br>2,7,8,9,10,14,16,20,21,28,32,39,40,41,42,49';}
       if(rr==22 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>6</strong> miembros: 13 <strong>control</strong><br>0,5,6,11,12,23,24,31,33,34,35,47,50';}
       if(rr==22 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>3,13,15,17,25,27,29,38,44,48';}
       if(rr==22 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>4</strong> miembros: 9 <br>1,4,18,19,30,37,43,45,46';}
       if(rr==22 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260427 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>36</strong> miembros: 3 <br>22,26,36';}
}
